@@ -30,12 +30,7 @@
 #'  conducted on new data (e.g. processing the outcome variable(s)).
 #'  Care should be taken when using `skip = TRUE` as it may affect
 #'  the computations for subsequent operations
-#' @return An updated version of `recipe` with the new step added to the
-#'  sequence of existing steps (if any).
-#' @keywords binning
-#' @concept preprocessing
-#' @concept discretization
-#' @concept factors
+#' @template step-return
 #' @export
 #' @details `step_discretize_cart()` creates non-uniform bins from numerical
 #'  variables by utilizing the information about the outcome variable and
@@ -170,32 +165,38 @@ cart_binning <- function(predictor, term, outcome, cost_complexity, tree_depth,
 #' @export
 prep.step_discretize_cart <- function(x, training, info = NULL, ...) {
   
-  col_names <- recipes::terms_select(terms = x$terms, info = info)
-  check_type(training[, col_names])
+  col_names <- recipes::recipes_eval_select(x$terms, training, info)
   
-  y_name <- recipes::terms_select(terms = x$outcome, info = info)
-  
-  col_names <- col_names[col_names != y_name]
-  
-  rules <-
-    purrr::map2(
-      training[, col_names],
-      col_names,
-      cart_binning,
-      outcome = training[[y_name]],
-      cost_complexity = x$cost_complexity,
-      tree_depth = x$tree_depth,
-      min_n = x$min_n
-    )
-
-  has_splits <- purrr::map_lgl(rules, ~ length(.x) >  0)
-  
-  rules <- rules[has_splits]
-  col_names <- col_names[has_splits]
   if (length(col_names) > 0) {
-    names(rules) <- col_names
+    check_type(training[, col_names])
+    
+    y_name <- recipes::recipes_eval_select(x$outcome, training, info)
+    
+    col_names <- col_names[col_names != y_name]
+    
+    rules <-
+      purrr::map2(
+        training[, col_names],
+        col_names,
+        cart_binning,
+        outcome = training[[y_name]],
+        cost_complexity = x$cost_complexity,
+        tree_depth = x$tree_depth,
+        min_n = x$min_n
+      )
+    
+    has_splits <- purrr::map_lgl(rules, ~ length(.x) >  0)
+    
+    rules <- rules[has_splits]
+    col_names <- col_names[has_splits]
+    if (length(col_names) > 0) {
+      names(rules) <- col_names
+    }
+  } else {
+    rules <- list()
   }
   
+  
   step_discretize_cart_new(
     terms = x$terms,
     role = x$role,
