@@ -5,6 +5,7 @@
 #'  be used to generate new parameter values and other characteristics.
 #' @param x A recipe step object
 #' @param ... Not used.
+#' @name tunable_embed
 #' @return A tibble object.
 #' @keywords internal
 #' @export
@@ -23,14 +24,14 @@ tunable.step_embed <- function(x, ...) {
 
 
 #' @export
-#' @rdname tunable.step_embed
+#' @rdname tunable_embed
 tunable.step_umap <- function(x, ...) {
   tibble::tibble(
     name = c("num_comp", "neighbors", "min_dist", "learn_rate", "epochs"),
     call_info = list(
       list(pkg = "dials", fun = "num_comp", range = c(1, 10)),
-      list(pkg = "dials", fun = "neighbors", range = c(5, 25)),
-      list(pkg = "dials", fun = "min_dist", range = c(-4, 0)),
+      list(pkg = "dials", fun = "neighbors", range = c(5, 200)),
+      list(pkg = "dials", fun = "min_dist", range = c(-4, -0.69897)),
       list(pkg = "dials", fun = "learn_rate"),
       list(pkg = "dials", fun = "epochs", range = c(100, 700))
     ),
@@ -41,7 +42,7 @@ tunable.step_umap <- function(x, ...) {
 }
 
 #' @export
-#' @rdname tunable.step_embed
+#' @rdname tunable_embed
 tunable.step_woe <- function(x, ...) {
   tibble::tibble(
     name = "Laplace",
@@ -55,7 +56,7 @@ tunable.step_woe <- function(x, ...) {
 }
 
 #' @export
-#' @rdname tunable.step_embed
+#' @rdname tunable_embed
 tunable.step_discretize_xgb <- function(x, ...) {
   tibble::tibble(
     name = c("sample_val", "learn_rate", "num_breaks", "tree_depth", "min_n"),
@@ -73,7 +74,7 @@ tunable.step_discretize_xgb <- function(x, ...) {
 }
 
 #' @export
-#' @rdname tunable.step_embed
+#' @rdname tunable_embed
 tunable.step_discretize_cart <- function(x, ...) {
   tibble::tibble(
     name = c("cost_complexity", "tree_depth", "min_n"),
@@ -87,3 +88,35 @@ tunable.step_discretize_cart <- function(x, ...) {
     component_id = x$id
   )
 }
+
+#' @rdname tunable_embed
+#' @export
+tunable.step_pca_sparse <- function(x, ...) {
+  tibble::tibble(
+    name = c("num_comp", "predictor_prop"),
+    call_info = list(
+      list(pkg = "dials", fun = "num_comp", range = c(1L, 10L)),
+      list(pkg = "dials", fun = "predictor_prop")
+    ),
+    source = "recipe",
+    component = "step_pca_sparse",
+    component_id = x$id
+  )
+}
+
+#' @rdname tunable_embed
+#' @export
+tunable.step_pca_sparse_bayes <- function(x, ...) {
+  tibble::tibble(
+    name = c("num_comp", "prior_slab_dispersion", "prior_mixture_threshold"),
+    call_info = list(
+      list(pkg = "dials", fun = "num_comp", range = c(1L, 10L)),
+      list(pkg = "dials", fun = "prior_slab_dispersion"),
+      list(pkg = "dials", fun = "prior_mixture_threshold")
+    ),
+    source = "recipe",
+    component = "step_pca_sparse_bayes",
+    component_id = x$id
+  )
+}
+
